#!/usr/bin/perl

# This is used as a diagnostic to send to the module author
#
#  perl dump.pl 2>&1 > dump.txt


use strict;

use Data::Dumper;
use Graphics::Framebuffer;
$Data::Dumper::Sortkeys = 1;

my $fb = Graphics::Framebuffer->new('SHOW_ERRORS' => 1);

my $copy = $fb;
delete($copy->{'SCREEN'});

print STDERR Dumper($copy);
